@@ -1,5 +1,6 @@
 import unittest
 
+
 class UnitTests(unittest.TestCase):
     def test_a(self):
         assert True
@@ -7,9 +8,6 @@ class UnitTests(unittest.TestCase):
     def test_b(self):
         assert True
 
-    @staticmethod
-    def test_e(self):
-        assert True
 
 def test_c():
     assert True
